@@ -2,17 +2,17 @@ test_that("compute_deriv_weights_gp works as expected!", {
 
   set.seed(9615)
   data <- generate_synthetic_data(sample_size = 200)
-  GPS_m <- train_gps(cov_mt = data[, -(1:2)],
-                     w_all = data$treat,
-                     sl_lib = c("SL.xgboost"),
-                     dnorm_log = FALSE)
+  gps_m <- estimate_gps(cov_mt = data[, -(1:2)],
+                        w_all = data$treat,
+                        sl_lib = c("SL.xgboost"),
+                        dnorm_log = FALSE)
 
   wi <- 4.2
   weights <- compute_deriv_weights_gp(w = wi,
                                       w_obs = data$treat,
-                                      GPS_m = GPS_m,
+                                      gps_m = gps_m,
                                       hyperparam = c(1, 1, 2))
 
   expect_equal(length(weights), nrow(data))
-  expect_equal(weights[37], 0.000708717, tolerance = 0.00001)
+  expect_equal(weights[37], 3.307249e-05, tolerance = 0.00001)
 })
